Module starknet_api::core
source · Structs
- A chain id.
- The hash of a ContractClass.
- The hash of a compiled ContractClass.
- The selector of an EntryPoint.
- An Ethereum address.
- The commitment on the events in a Block.
- The root of the global state at a Block and StateUpdate.
- A general type for nonces.
- A key for nodes of a Patricia tree.
- A public key of a sequencer.
- The commitment on the transactions in a Block.
Constants
- The prefix used in the calculation of a contract address.
- The maximal size of storage var.
Statics
- The size of the contract address domain.
- The address upper bound; it is defined to be congruent with the storage var address upper bound.