Struct starknet_api::state::StateUpdate
source · pub struct StateUpdate {
pub block_hash: BlockHash,
pub new_root: GlobalRoot,
pub old_root: GlobalRoot,
pub state_diff: StateDiff,
}Expand description
The differences between two states before and after a block with hash block_hash and their respective roots.
Fields
block_hash: BlockHashnew_root: GlobalRootold_root: GlobalRootstate_diff: StateDiffTrait Implementations
sourceimpl Clone for StateUpdate
impl Clone for StateUpdate
sourcefn clone(&self) -> StateUpdate
fn clone(&self) -> StateUpdate
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for StateUpdate
impl Debug for StateUpdate
sourceimpl Default for StateUpdate
impl Default for StateUpdate
sourcefn default() -> StateUpdate
fn default() -> StateUpdate
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for StateUpdate
impl<'de> Deserialize<'de> for StateUpdate
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for StateUpdate
impl PartialEq for StateUpdate
sourcefn eq(&self, other: &StateUpdate) -> bool
fn eq(&self, other: &StateUpdate) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for StateUpdate
impl Serialize for StateUpdate
impl Eq for StateUpdate
impl StructuralPartialEq for StateUpdate